<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Filtros de transformação de imagens e de cores',
	'images_slogan' => 'Filtros de transformação de imagens e de cores',
];
